@@ -1,7 +1,7 @@
 from django import template
 from django.template import Library, Node
 from django.db.models import get_model
-
+from newscenter.models import Category
 
 register = Library()
 
@@ -34,3 +34,16 @@ class FeaturedNode(Node):
 
     get_news = register.tag(get_news)
 
+class CategoryNode(Node):
+    def render(self, context):
+        try:
+            context['category_list'] = Category.objects.all()
+        except:
+            raise template.TemplateSyntaxError, ""
+
+        return ''
+
+    def show_categories(parser, token):
+        return CategoryNode()
+
+    show_categories = register.tag(show_categories)
